//@line 36 "/builds/slave/rel-m-rel-lnx-mb-rpk-6/mozilla-release/uk/mobile/mobile-l10n.js"

//@line 38 "/builds/slave/rel-m-rel-lnx-mb-rpk-6/mozilla-release/uk/mobile/mobile-l10n.js"
 
pref("general.useragent.locale", "uk");
